@@ -24,6 +24,8 @@ use 5.006;
 use strict;
 use warnings;
 
+use Carp;
+
 use overload
 	"+"    => \&_overload_addition,
 	"-"    => \&_overload_subtraction,
@@ -41,7 +43,7 @@ use overload
 
 use Math::Symbolic::ExportConstants qw/:all/;
 
-our $VERSION = '0.106';
+our $VERSION = '0.108';
 
 =head1 METHODS
 
@@ -62,6 +64,54 @@ sub to_string {
 
 
 
+=head2 Method value
+
+value() evaluates the Math::Symbolic tree to its numeric representation.
+
+value() without arguments requires that every variable in the tree contains
+a defined value attribute. Please note that this refers to every variable
+I<object>, not just every named variable.
+
+value() with one argument sets the object's value.
+
+value() with named arguments (key/value pairs) associates variables in the tree
+with the value-arguments if the corresponging key matches the variable name.
+(Can one say this any more complicated?)
+
+Example: $tree->value(x => 1, y => 2, z => 3, t => 0) assigns the value 1 to
+any occurrances of variables of the name "x", aso.
+
+=cut
+
+sub value {
+	croak "This is a method stub from Math::Symbolic::Base. Implement me.";
+}
+
+
+
+=head2 Method set_value
+
+set_value() returns nothing.
+
+set_value() requires named arguments (key/value pairs) that associate
+variable names of variables in the tree with the value-arguments if the
+corresponging key matches the variable name.
+(Can one say this any more complicated?)
+
+Example: $tree->set_value(x => 1, y => 2, z => 3, t => 0) assigns the value 1
+to any occurrances of variables of the name "x", aso.
+
+As opposed to value(), set_value() assigns to the variables I<permanently>
+and does not evaluate the tree.
+
+=cut
+
+sub set_value {
+	croak "This is a method stub from Math::Symbolic::Base. Implement me.";
+}
+
+
+
 =head2 Method simplify
 
 Minimum method for term simpilification just clones.
@@ -95,7 +145,7 @@ Returns the type of the term. This is a stub to be overridden.
 =cut
 
 sub term_type {
-	die "term_type not defined for " . __PACKAGE__;
+	croak "term_type not defined for " . __PACKAGE__;
 }
 
 
