@@ -55,7 +55,7 @@ use Math::Symbolic::Derivative qw//;
 
 use base 'Math::Symbolic::Base';
 
-our $VERSION = '0.106';
+our $VERSION = '0.108';
 
 =head1 CLASS DATA
 
@@ -688,13 +688,53 @@ sub apply {
 
 =head2 Method value
 
-For operators, value() is just a wrapper around apply().
+value() evaluates the Math::Symbolic tree to its numeric representation.
+
+value() without arguments requires that every variable in the tree contains
+a defined value attribute. Please note that this refers to every variable
+I<object>, not just every named variable.
+
+value() with one argument sets the object's value (not in case of
+operators).
+
+value() with named arguments (key/value pairs) associates variables in the tree
+with the value-arguments if the corresponging key matches the variable name.
+(Can one say this any more complicated?)
+
+Example: $tree->value(x => 1, y => 2, z => 3, t => 0) assigns the value 1 to
+any occurrances of variables of the name "x", aso.
 
 =cut
 
 sub value {
 	my $self = shift;
-	return $self->apply()->value();
+	return $self->apply()->value(@_);
+}
+
+
+
+=head2 Method set_value
+
+set_value() returns nothing.
+
+set_value() requires named arguments (key/value pairs) that associate
+variable names of variables in the tree with the value-arguments if the
+corresponging key matches the variable name.
+(Can one say this any more complicated?)
+
+Example: $tree->set_value(x => 1, y => 2, z => 3, t => 0) assigns the value 1
+to any occurrances of variables of the name "x", aso.
+
+As opposed to value(), set_value() assigns to the variables I<permanently>
+and does not evaluate the tree.
+
+=cut
+
+sub set_value {
+	my $self = shift;
+	foreach (@{$self->{operands}}) {
+		$_->set_value(@_);
+	}
 }
 
 
