@@ -41,7 +41,7 @@ use Math::Symbolic::ExportConstants qw/:all/;
 
 use base 'Math::Symbolic::Base';
 
-our $VERSION = '0.106';
+our $VERSION = '0.108';
 
 =head1 METHODS
 
@@ -86,17 +86,68 @@ sub new {
 
 =head2 Method value
 
-Optional argument: sets the object's value.
-Returns the object's value.
+value() evaluates the Math::Symbolic tree to its numeric representation.
+
+value() without arguments requires that every variable in the tree contains
+a defined value attribute. Please note that this refers to every variable
+I<object>, not just every named variable.
+
+value() with one argument sets the object's value.
+
+value() with named arguments (key/value pairs) associates variables in the tree
+with the value-arguments if the corresponging key matches the variable name.
+(Can one say this any more complicated?)
+
+Example: $tree->value(x => 1, y => 2, z => 3, t => 0) assigns the value 1 to
+any occurrances of variables of the name "x", aso.
 
 =cut
 
 sub value {
 	my $self = shift;
-	if (@_) {
+	if (@_==1) {
 		$self->{value} = shift;
+		return $self->{value};
+	}
+	elsif (@_==0) {
+		return $self->{value};
+	}
+	else {
+		my %args = @_;
+		if (exists $args{$self->{name}}) {
+			return $args{$self->{name}};
+		}
+		else {
+			return $self->{value};
+		}
+	}
+}
+
+
+
+=head2 Method set_value
+
+set_value() returns nothing.
+
+set_value() requires named arguments (key/value pairs) that associate
+variable names of variables in the tree with the value-arguments if the
+corresponging key matches the variable name.
+(Can one say this any more complicated?)
+
+Example: $tree->set_value(x => 1, y => 2, z => 3, t => 0) assigns the value 1
+to any occurrances of variables of the name "x", aso.
+
+As opposed to value(), set_value() assigns to the variables I<permanently>
+and does not evaluate the tree.
+
+=cut
+
+sub set_value {
+	my $self = shift;
+	my %args = @_;
+	if (exists $args{$self->{name}}) {
+		$self->{value} = $args{$self->{name}};
 	}
-	return $self->{value};
 }
 
 
